package defaults

import (
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/abbysale"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/abuseipdb"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/accuweather"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/adafruitio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/adzuna"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aeroworkflow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/agora"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aha"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airbrakeprojectkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airbrakeuserkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airship"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airtableapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airtableoauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airtablepersonalaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airvisual"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aiven"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/alchemy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/alegra"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aletheiaapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/algoliaadminkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/alibaba"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/alienvault"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/allsports"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/amadeus"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ambee"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/amplitudeapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/anthropic"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/anypoint"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apacta"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/api2cart"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apideck"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apiflash"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apifonica"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apilayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apimatic"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apimetrics"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apitemplate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/appcues"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/appfollow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/appointedd"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/appoptics"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/appsynergy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apptivo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/artsy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/asanaoauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/asanapersonalaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/assemblyai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/atera"
	atlassianv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/atlassian/v1"
	atlassianv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/atlassian/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/audd"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/auth0managementapitoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/auth0oauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/autodesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/autoklose"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/autopilot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/avazapersonalaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aviationstack"
	aws_access_keys "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aws/access_keys"
	aws_session_keys "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aws/session_keys"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/axonaut"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aylien"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ayrshare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azure_batch"
	azure_entra_refreshtoken "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azure_entra/refreshtoken"
	azure_entra_serviceprincipal_v1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azure_entra/serviceprincipal/v1"
	azure_entra_serviceprincipal_v2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azure_entra/serviceprincipal/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azure_openai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azure_storage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azurecontainerregistry"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azuredevopspersonalaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azuresearchadminkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azuresearchquerykey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bannerbear"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/baremetrics"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/beamer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/beebole"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/besnappy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/besttime"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/betterstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/billomat"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitbar"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitcoinaverage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitfinex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitlyaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitmex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/blazemeter"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/blitapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/blogger"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bombbomb"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/boostnote"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/borgbase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/box"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/boxoauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/braintreepayments"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/brandfetch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/browserstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/browshot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bscscan"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/buddyns"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/budibase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bugherd"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bugsnag"
	buildKitev1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/buildkite/v1"
	buildKitev2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/buildkite/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bulbul"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bulksms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/buttercms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/caflou"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/calendarific"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/calendlyapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/calorieninja"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/campayn"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cannyio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/capsulecrm"
	captainDataV1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/captaindata/v1"
	captainDataV2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/captaindata/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/carboninterface"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cashboard"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/caspio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/censys"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/centralstationcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cexio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/chartmogul"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/chatbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/chatfule"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/checio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/checklyhq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/checkout"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/checkvist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cicero"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/circleci"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clarifai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clearbit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clickhelp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clicksendsms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clickuppersonaltoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cliengo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clinchpad"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clockify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clockworksms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/closecrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudconvert"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudelements"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudflareapitoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudflarecakey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudflareglobalapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudimage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudmersive"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudplan"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudsmith"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloverly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloze"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clustdoc"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coda"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/codacy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/codeclimate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/codemagic"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/codequiry"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coinapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coinbase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coinbase_waas"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coinlayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coinlib"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/collect2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/column"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/commercejs"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/commodities"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/companyhub"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/confluent"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/contentfulpersonalaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/conversiontools"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/convertapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/convertkit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/convier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/copper"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/couchbase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/countrylayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/courier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coveralls"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/craftmypdf"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/crowdin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cryptocompare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currencycloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currencyfreaks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currencylayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currencyscoop"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currentsapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/customerguru"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/customerio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/d7network"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dandelion"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dareboost"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/databox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/databrickstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/datadogtoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/datagov"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/deepai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/deepgram"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/delighted"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/demio"
	denodeploy "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/deno"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/deputy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/detectify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/detectlanguage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dfuse"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/diffbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/diggernaut"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/digitaloceantoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/digitaloceanv2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/discordbottoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/discordwebhook"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/disqus"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ditto"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dnscheck"
	dockerhubv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dockerhub/v1"
	dockerhubv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dockerhub/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/docparser"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/documo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/docusign"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/doppler"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dotmailer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dovico"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dronahq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/droneci"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dropbox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/duply"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dwolla"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dynalist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dyspatch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/eagleeyenetworks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/easyinsight"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ecostruxureit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/edamam"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/edenai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/eightxeight"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/elasticemail"
	elevenlabsv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/elevenlabs/v1"
	elevenlabsv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/elevenlabs/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/enablex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/endorlabs"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/enigma"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/envoyapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/eraser"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/etherscan"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ethplorer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/eventbrite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/everhour"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/exchangerateapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/exchangeratesapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/exportsdk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/extractorapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/facebookoauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/faceplusplus"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fastforex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fastlypersonaltoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/feedier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fetchrss"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fibery"
	figmapersonalaccesstokenv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/figmapersonalaccesstoken/v1"
	figmapersonalaccesstokenv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/figmapersonalaccesstoken/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fileio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/finage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/financialmodelingprep"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/findl"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/finnhub"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fixerio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flatio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fleetbase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flexport"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flickr"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flightapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flightlabs"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flightstats"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/float"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flowflu"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flutterwave"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fmfw"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/formbucket"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/formcraft"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/formio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/formsite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/foursquare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/frameio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/freshbooks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/freshdesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/front"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ftp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fulcrum"
	fullstoryv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fullstory/v1"
	fullstoryv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fullstory/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fxmarket"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gcp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gcpapplicationdefaultcredentials"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geckoboard"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gemini"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gengo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geoapify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geocode"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geocodify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geocodio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geoipifi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/getgeoapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/getgist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/getresponse"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/getsandbox"
	githubv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/github/v1"
	githubv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/github/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/github_oauth2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/githubapp"
	gitlabv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gitlab/v1"
	gitlabv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gitlab/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gitter"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/glassnode"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gocanvas"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gocardless"
	godaddyv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/godaddy/v1"
	godaddyv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/godaddy/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/goodday"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/googleoauth2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/grafana"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/grafanaserviceaccount"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/graphcms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/graphhopper"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/groovehq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/groq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gtmetrix"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/guardianapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gumroad"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gyazo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/happyscribe"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/harvest"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hellosign"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/helpcrunch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/helpscout"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hereapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/heroku"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hiveage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/holidayapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/holistic"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/honeycomb"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/host"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/html2pdf"
	hubspot_apikey_v1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hubspot_apikey/v1"
	hubspot_apikey_v2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hubspot_apikey/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/huggingface"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/humanity"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hunter"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hybiscus"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hypertrack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/iconfinder"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/iexapis"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/iexcloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/imagekit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/imagga"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/impala"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/infura"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/insightly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/instabot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/instamojo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/intercom"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/interseller"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/intra42"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/intrinio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/invoiceocean"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ip2location"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipgeolocation"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipinfodb"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipquality"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jdbc"
	jiratokenv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jiratoken/v1"
	jiratokenv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jiratoken/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jotform"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jumpcloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jupiterone"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/juro"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kanban"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kanbantool"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/karmacrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/keenio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kickbox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/klaviyo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/klipfolio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/knapsackpro"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kontent"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kraken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kucoin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kylas"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/languagelayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/larksuite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/larksuiteapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/launchdarkly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ldap"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/leadfeeder"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lemlist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lemonsqueezy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lendflow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lessannoyingcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lexigram"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/linearapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/linenotify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/linkpreview"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/liveagent"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/livestorm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/loadmill"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/locationiq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/loggly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/loginradius"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/logzio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lokalisetoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/loyverse"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lunchmoney"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/luno"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/madkudu"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/magicbell"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailboxlayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailchimp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailerlite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailgun"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailjetbasicauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailjetsms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailmodo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailsac"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mandrill"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mapbox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mapquest"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/marketstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mattermostpersonaltoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mavenlink"
	maxmindlicensev1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/maxmindlicense/v1"
	maxmindlicensev2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/maxmindlicense/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/meaningcloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mediastack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/meistertask"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/meraki"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mesibo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/messagebird"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/metaapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/metabase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/metrilo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/microsoftteamswebhook"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mindmeister"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/miro"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mixmax"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mockaroo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/moderation"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/monday"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mongodb"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/monkeylearn"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/moonclerk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/moosend"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/moralis"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mrticktock"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mux"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/myfreshworks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/myintervals"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nethunt"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/netlify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/netsuite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/neutrinoapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/newrelicpersonalapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/newsapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/newscatcher"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nexmoapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nftport"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ngc"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ngrok"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nicereply"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nightfall"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nimble"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/noticeable"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/notion"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nozbeteams"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/npmtoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/npmtokenv2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nugetapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/numverify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nutritionix"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nvapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nylas"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/oanda"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/okta"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/omnisend"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onedesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onelogin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onepagecrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onesignal"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onfleet"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/oopspam"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/openai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/opencagedata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/openuv"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/openvpn"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/openweather"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/opsgenie"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/optimizely"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/overloop"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/owlbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/packagecloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pagarme"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pagerdutyapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pandadoc"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pandascore"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paperform"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paralleldots"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/parsehub"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/parsers"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/parseur"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/partnerstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pastebin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paydirtapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paymoapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paymongo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paypaloauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paystack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pdflayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pdfshift"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/peopledatalabs"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pepipost"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/percy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pinata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pipedream"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pipedrive"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pivotaltracker"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pixabay"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/planetscale"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/planetscaledb"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/planviewleankit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/planyo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/plivo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/podio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pollsapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/poloniex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/polygon"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/portainer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/portainertoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/positionstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/postageapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/postbacks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/postgres"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/posthog"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/postman"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/postmark"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/powrbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/prefect"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/privacy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/privatekey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/prodpad"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/prospectcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/protocolsio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/proxycrawl"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pubnubpublishkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pubnubsubscriptionkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pulumi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/purestake"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pushbulletapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pusherchannelkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pypi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/qase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/qualaroo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/qubole"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rabbitmq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/railwayapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ramp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rapidapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rawg"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/razorpay"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/reachmail"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/readme"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/reallysimplesystems"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rebrandly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rechargepayments"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/redis"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/refiner"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rentman"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/repairshopr"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/replicate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/replyio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/requestfinance"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/restpackhtmltopdfapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/restpackscreenshotapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/revampcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ringcentral"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ritekit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/roaring"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/robinhoodcrypto"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rocketreach"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/roninapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/route4me"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rownd"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rubygems"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/runrunit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/saladcloudapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/salesblink"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/salescookie"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/salesflare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/salesforce"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/salesmate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sanity"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/satismeterprojectkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/satismeterwritekey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/saucelabs"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scalewaykey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scalr"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapeowl"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scraperapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scraperbox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapestack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapfly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapingant"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapingbee"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/screenshotapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/screenshotlayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrutinizerci"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/securitytrails"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/segmentapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/selectpdf"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/semaphore"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sendbird"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sendbirdorganizationapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sendgrid"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sendinbluev2"
	sentrytokenv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sentrytoken/v1"
	sentrytokenv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sentrytoken/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/serphouse"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/serpstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sheety"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sherpadesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shipday"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shodankey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shopify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shortcut"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shotstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shutterstock"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shutterstockoauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/signable"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/signalwire"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/signaturit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/signupgenius"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sigopt"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/simfin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/simplesat"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/simplynoted"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/simvoly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sinchmessage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sirv"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/siteleaf"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/skrappio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/skybiometry"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/slack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/slackwebhook"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/smartsheets"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/smartystreets"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/smooch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/snipcart"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/snowflake"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/snykkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sonarcloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sourcegraph"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sourcegraphcody"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/speechtextai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/splunkobservabilitytoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/spoonacular"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sportsmonk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sqlserver"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/square"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/squareapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/squarespace"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/squareup"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sslmate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/statuscake"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/statuspage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/statuspal"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stitchdata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stockdata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/storecove"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stormboard"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stormglass"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/storyblok"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/storychief"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/strava"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/streak"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stripe"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stripo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stytch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sugester"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sumologickey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/supabasetoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/supernotesapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/surveyanyplace"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/surveybot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/surveysparrow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/survicate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/swell"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/swiftype"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tailscale"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tallyfy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tatumio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/taxjar"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teamgate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teamworkcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teamworkdesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teamworkspaces"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/technicalanalysisapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tefter"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/telegrambottoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teletype"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/telnyx"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/terraformcloudpersonaltoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/testingbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/textmagic"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/theoddsapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/thinkific"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/thousandeyes"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ticketmaster"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tickettailor"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tiingo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/timecamp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/timezoneapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tineswebhook"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tmetric"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/todoist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tokeet"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tomorrowio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tomtom"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tradier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/transferwise"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/travelpayouts"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/travisci"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/trelloapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/trufflehogenterprise"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twelvedata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twilio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twilioapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twitch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twitchaccesstoken"
	twitterv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twitter/v1"
	twitterv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twitter/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twitterconsumerkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tyntec"
	typeformv1 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/typeform/v1"
	typeformv2 "github.com/trufflesecurity/trufflehog/v3/pkg/detectors/typeform/v2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/typetalk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ubidots"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uclassify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/unifyid"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/unplugg"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/unsplash"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/upcdatabase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uplead"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uploadcare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uptimerobot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/upwave"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uri"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/urlscan"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/userflow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/userstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vagrantcloudpersonaltoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vatlayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vbout"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vercel"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/verifier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/verimail"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/veriphone"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/versioneye"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/viewneo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/virustotal"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/visualcrossing"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/voiceflow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/voicegain"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/voodoosms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vouchery"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vpnapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vultrapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vyte"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/walkscore"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/weatherbit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/weatherstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/web3storage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/webex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/webflow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/webscraper"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/webscraping"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/websitepulse"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/weightsandbiases"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/whoxy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/wistia"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/wiz"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/worksnaps"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/workstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/worldcoinindex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/worldweather"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/wrike"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/yandex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/yelp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/youneedabudget"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/yousign"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/youtubeapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zendeskapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zenkitapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zenrows"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zenscrape"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zenserp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zeplin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zerobounce"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zerotier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zipapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zipbooks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zipcodeapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zipcodebase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zohocrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zonkafeedback"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zulipchat"
	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/detectorspb"
)

func buildDetectorList() []detectors.Detector {
	return []detectors.Detector{
		&abbysale.Scanner{},
		// &abstract.Scanner{},
		&abuseipdb.Scanner{},
		&accuweather.Scanner{},
		&adafruitio.Scanner{},
		// &adobeio.Scanner{},
		&adzuna.Scanner{},
		&aeroworkflow.Scanner{},
		&agora.Scanner{},
		&aha.Scanner{},
		&airbrakeprojectkey.Scanner{},
		&airbrakeuserkey.Scanner{},
		&airship.Scanner{},
		&airtableapikey.Scanner{},
		&airtableoauth.Scanner{},
		&airtablepersonalaccesstoken.Scanner{},
		&airvisual.Scanner{},
		&aiven.Scanner{},
		&alchemy.Scanner{},
		// The service currently has blocked requests with a "TruffleHog" UserAgent.
		// &alconost.Scanner{},
		&alegra.Scanner{},
		&aletheiaapi.Scanner{},
		&algoliaadminkey.Scanner{},
		&alibaba.Scanner{},
		&alienvault.Scanner{},
		&allsports.Scanner{},
		&amadeus.Scanner{},
		&ambee.Scanner{},
		&amplitudeapikey.Scanner{},
		&anthropic.Scanner{},
		&anypoint.Scanner{},
		&apacta.Scanner{},
		&api2cart.Scanner{},
		&apideck.Scanner{},
		&apiflash.Scanner{},
		&apifonica.Scanner{},
		&apify.Scanner{},
		&apilayer.Scanner{},
		&apimatic.Scanner{},
		&apimetrics.Scanner{},
		&apitemplate.Scanner{},
		// &apollo.Scanner{},
		&appcues.Scanner{},
		&appfollow.Scanner{},
		&appointedd.Scanner{},
		&appoptics.Scanner{},
		&appsynergy.Scanner{},
		&apptivo.Scanner{},
		// &artifactory.Scanner{},
		&artsy.Scanner{},
		&asanaoauth.Scanner{},
		&asanapersonalaccesstoken.Scanner{},
		&assemblyai.Scanner{},
		&atera.Scanner{},
		&atlassianv1.Scanner{},
		&atlassianv2.Scanner{},
		&audd.Scanner{},
		&auth0managementapitoken.Scanner{},
		&auth0oauth.Scanner{},
		&autodesk.Scanner{},
		&autoklose.Scanner{},
		&autopilot.Scanner{},
		&avazapersonalaccesstoken.Scanner{},
		&aviationstack.Scanner{},
		aws_access_keys.New(),
		aws_session_keys.New(),
		&axonaut.Scanner{},
		&aylien.Scanner{},
		&ayrshare.Scanner{},
		&azure_entra_refreshtoken.Scanner{},
		&azure_entra_serviceprincipal_v1.Scanner{},
		&azure_entra_serviceprincipal_v2.Scanner{},
		&azure_batch.Scanner{},
		&azurecontainerregistry.Scanner{},
		&azuredevopspersonalaccesstoken.Scanner{},
		// &azurefunctionkey.Scanner{}, // detector is throwing some FPs
		&azure_openai.Scanner{},
		&azuresearchadminkey.Scanner{},
		&azuresearchquerykey.Scanner{},
		&azure_storage.Scanner{},
		&bannerbear.Scanner{},
		&baremetrics.Scanner{},
		&beamer.Scanner{},
		&beebole.Scanner{},
		&besnappy.Scanner{},
		&besttime.Scanner{},
		&betterstack.Scanner{},
		&billomat.Scanner{},
		&bitbar.Scanner{},
		&bitcoinaverage.Scanner{},
		&bitfinex.Scanner{},
		&bitlyaccesstoken.Scanner{},
		&bitmex.Scanner{},
		&blazemeter.Scanner{},
		&blitapp.Scanner{},
		// &blocknative.Scanner{}, // temporary disabled due to API issue
		&blogger.Scanner{},
		&bombbomb.Scanner{},
		&boostnote.Scanner{},
		&borgbase.Scanner{},
		&box.Scanner{},
		&boxoauth.Scanner{},
		&braintreepayments.Scanner{},
		&brandfetch.Scanner{},
		&browserstack.Scanner{},
		&browshot.Scanner{},
		&bscscan.Scanner{},
		&buddyns.Scanner{},
		&budibase.Scanner{},
		&bugherd.Scanner{},
		&bugsnag.Scanner{},
		&buildKitev1.Scanner{},
		&buildKitev2.Scanner{},
		&bulbul.Scanner{},
		&bulksms.Scanner{},
		&buttercms.Scanner{},
		&caflou.Scanner{},
		&calendarific.Scanner{},
		&calendlyapikey.Scanner{},
		&calorieninja.Scanner{},
		&campayn.Scanner{},
		&cannyio.Scanner{},
		&capsulecrm.Scanner{},
		&captainDataV1.Scanner{},
		&captainDataV2.Scanner{},
		&carboninterface.Scanner{},
		&cashboard.Scanner{},
		&caspio.Scanner{},
		&censys.Scanner{},
		&centralstationcrm.Scanner{},
		&cexio.Scanner{},
		&chartmogul.Scanner{},
		&chatbot.Scanner{},
		&chatfule.Scanner{},
		&checio.Scanner{},
		&checklyhq.Scanner{},
		&checkout.Scanner{},
		&checkvist.Scanner{},
		&cicero.Scanner{},
		&circleci.Scanner{},
		&clarifai.Scanner{},
		&clearbit.Scanner{},
		&clickhelp.Scanner{},
		&clicksendsms.Scanner{},
		&clickuppersonaltoken.Scanner{},
		&cliengo.Scanner{},
		&clinchpad.Scanner{},
		&clockify.Scanner{},
		&clockworksms.Scanner{},
		&closecrm.Scanner{},
		&cloudconvert.Scanner{},
		&cloudelements.Scanner{},
		&cloudflareapitoken.Scanner{},
		&cloudflarecakey.Scanner{},
		&cloudflareglobalapikey.Scanner{},
		&cloudimage.Scanner{},
		&cloudmersive.Scanner{},
		&cloudplan.Scanner{},
		&cloudsmith.Scanner{},
		&cloverly.Scanner{},
		&cloze.Scanner{},
		&clustdoc.Scanner{},
		&coda.Scanner{},
		&codacy.Scanner{},
		&codeclimate.Scanner{},
		&codemagic.Scanner{},
		&codequiry.Scanner{},
		&coinapi.Scanner{},
		&coinbase.Scanner{},
		&coinbase_waas.Scanner{},
		&coinlayer.Scanner{},
		&coinlib.Scanner{},
		&collect2.Scanner{},
		&column.Scanner{},
		&commercejs.Scanner{},
		&commodities.Scanner{},
		&companyhub.Scanner{},
		&confluent.Scanner{},
		&contentfulpersonalaccesstoken.Scanner{},
		&conversiontools.Scanner{},
		&convertapi.Scanner{},
		&convertkit.Scanner{},
		&convier.Scanner{},
		&copper.Scanner{},
		&couchbase.Scanner{},
		&countrylayer.Scanner{},
		&courier.Scanner{},
		&coveralls.Scanner{},
		&craftmypdf.Scanner{},
		&crowdin.Scanner{},
		&cryptocompare.Scanner{},
		&currencycloud.Scanner{},
		&currencyfreaks.Scanner{},
		&currencylayer.Scanner{},
		&currencyscoop.Scanner{},
		&currentsapi.Scanner{},
		&customerguru.Scanner{},
		&customerio.Scanner{},
		&d7network.Scanner{},
		// &dailyco.Scanner{},
		&dandelion.Scanner{},
		&dareboost.Scanner{},
		&databox.Scanner{},
		&databrickstoken.Scanner{},
		&datadogtoken.Scanner{},
		&datagov.Scanner{},
		// &debounce.Scanner{},
		&deepai.Scanner{},
		&deepgram.Scanner{},
		&delighted.Scanner{},
		&demio.Scanner{},
		&denodeploy.Scanner{},
		&deputy.Scanner{},
		&detectify.Scanner{},
		&detectlanguage.Scanner{},
		&dfuse.Scanner{},
		&diffbot.Scanner{},
		&diggernaut.Scanner{},
		&digitaloceantoken.Scanner{},
		&digitaloceanv2.Scanner{},
		&discordbottoken.Scanner{},
		&discordwebhook.Scanner{},
		&disqus.Scanner{},
		&ditto.Scanner{},
		&dnscheck.Scanner{},
		&dockerhubv1.Scanner{},
		&dockerhubv2.Scanner{},
		&docparser.Scanner{},
		&documo.Scanner{},
		&docusign.Scanner{},
		&doppler.Scanner{},
		&dotmailer.Scanner{},
		&dovico.Scanner{},
		&dronahq.Scanner{},
		&droneci.Scanner{},
		&dropbox.Scanner{},
		&duply.Scanner{},
		&dwolla.Scanner{},
		&dynalist.Scanner{},
		&dyspatch.Scanner{},
		&eagleeyenetworks.Scanner{},
		&easyinsight.Scanner{},
		&ecostruxureit.Scanner{},
		&edamam.Scanner{},
		&edenai.Scanner{},
		&eightxeight.Scanner{},
		&elasticemail.Scanner{},
		&elevenlabsv1.Scanner{},
		&elevenlabsv2.Scanner{},
		&enablex.Scanner{},
		&endorlabs.Scanner{},
		&enigma.Scanner{},
		&envoyapikey.Scanner{},
		&eraser.Scanner{},
		&etherscan.Scanner{},
		&ethplorer.Scanner{},
		&eventbrite.Scanner{},
		&everhour.Scanner{},
		&exchangerateapi.Scanner{},
		&exchangeratesapi.Scanner{},
		&exportsdk.Scanner{},
		&extractorapi.Scanner{},
		&facebookoauth.Scanner{},
		&faceplusplus.Scanner{},
		&fastforex.Scanner{},
		&fastlypersonaltoken.Scanner{},
		&feedier.Scanner{},
		&fetchrss.Scanner{},
		&fibery.Scanner{},
		&figmapersonalaccesstokenv1.Scanner{},
		&figmapersonalaccesstokenv2.Scanner{},
		&fileio.Scanner{},
		&finage.Scanner{},
		&financialmodelingprep.Scanner{},
		&findl.Scanner{},
		&finnhub.Scanner{},
		&fixerio.Scanner{},
		&flatio.Scanner{},
		&fleetbase.Scanner{},
		&flexport.Scanner{},
		&flickr.Scanner{},
		&flightapi.Scanner{},
		&flightlabs.Scanner{},
		&flightstats.Scanner{},
		&float.Scanner{},
		&flowflu.Scanner{},
		&flutterwave.Scanner{},
		&fmfw.Scanner{},
		&formbucket.Scanner{},
		&formcraft.Scanner{},
		&formio.Scanner{},
		&formsite.Scanner{},
		&foursquare.Scanner{},
		&frameio.Scanner{},
		&freshbooks.Scanner{},
		&freshdesk.Scanner{},
		&front.Scanner{},
		&ftp.Scanner{},
		&fulcrum.Scanner{},
		&fullstoryv1.Scanner{},
		&fullstoryv2.Scanner{},
		&fxmarket.Scanner{},
		&gcp.Scanner{},
		&gcpapplicationdefaultcredentials.Scanner{},
		&geckoboard.Scanner{},
		&gemini.Scanner{},
		// &generic.Scanner{},
		&gengo.Scanner{},
		&geoapify.Scanner{},
		&geocode.Scanner{},
		&geocodify.Scanner{},
		&geocodio.Scanner{},
		&geoipifi.Scanner{},
		// &getemail.Scanner{},
		// &getemails.Scanner{},
		&getgeoapi.Scanner{},
		&getgist.Scanner{},
		&getresponse.Scanner{},
		&getsandbox.Scanner{},
		&github_oauth2.Scanner{},
		&githubapp.Scanner{},
		&githubv1.Scanner{},
		&githubv2.Scanner{},
		&gitlabv1.Scanner{},
		&gitlabv2.Scanner{},
		&gitter.Scanner{},
		&glassnode.Scanner{},
		&gocanvas.Scanner{},
		&gocardless.Scanner{},
		&godaddyv1.Scanner{},
		&godaddyv2.Scanner{},
		&goodday.Scanner{},
		&googleoauth2.Scanner{},
		&grafana.Scanner{},
		&grafanaserviceaccount.Scanner{},
		&graphcms.Scanner{},
		&graphhopper.Scanner{},
		&groovehq.Scanner{},
		&groq.Scanner{},
		&gtmetrix.Scanner{},
		&guardianapi.Scanner{},
		&gumroad.Scanner{},
		&gyazo.Scanner{},
		&happyscribe.Scanner{},
		&harvest.Scanner{},
		&hellosign.Scanner{},
		&helpcrunch.Scanner{},
		&helpscout.Scanner{},
		&hereapi.Scanner{},
		&heroku.Scanner{},
		// &hive.Scanner{},
		&hiveage.Scanner{},
		&holidayapi.Scanner{},
		&holistic.Scanner{},
		&honeycomb.Scanner{},
		&host.Scanner{},
		&html2pdf.Scanner{},
		&hubspot_apikey_v1.Scanner{},
		&hubspot_apikey_v2.Scanner{},
		&huggingface.Scanner{},
		&humanity.Scanner{},
		&hunter.Scanner{},
		&hybiscus.Scanner{},
		&hypertrack.Scanner{},
		// &ibmclouduserkey.Scanner{},
		&iconfinder.Scanner{},
		&iexapis.Scanner{},
		&iexcloud.Scanner{},
		&imagekit.Scanner{},
		&imagga.Scanner{},
		&impala.Scanner{},
		&infura.Scanner{},
		&insightly.Scanner{},
		&instabot.Scanner{},
		&instamojo.Scanner{},
		&intercom.Scanner{},
		&interseller.Scanner{},
		&intra42.Scanner{},
		&intrinio.Scanner{},
		&invoiceocean.Scanner{},
		&ip2location.Scanner{},
		&ipapi.Scanner{},
		&ipgeolocation.Scanner{},
		&ipinfodb.Scanner{},
		&ipquality.Scanner{},
		&ipstack.Scanner{},
		&jdbc.Scanner{},
		&jiratokenv1.Scanner{},
		&jiratokenv2.Scanner{},
		&jotform.Scanner{},
		&jumpcloud.Scanner{},
		&jupiterone.Scanner{},
		&juro.Scanner{},
		&kanban.Scanner{},
		&kanbantool.Scanner{},
		&karmacrm.Scanner{},
		&keenio.Scanner{},
		&kickbox.Scanner{},
		&klaviyo.Scanner{},
		&klipfolio.Scanner{},
		&knapsackpro.Scanner{},
		&kontent.Scanner{},
		&kraken.Scanner{},
		&kucoin.Scanner{},
		&kylas.Scanner{},
		&languagelayer.Scanner{},
		&larksuite.Scanner{},
		&larksuiteapikey.Scanner{},
		&launchdarkly.Scanner{},
		&ldap.Scanner{},
		&leadfeeder.Scanner{},
		&lemlist.Scanner{},
		&lemonsqueezy.Scanner{},
		&lendflow.Scanner{},
		&lessannoyingcrm.Scanner{},
		&lexigram.Scanner{},
		&linearapi.Scanner{},
		// &linemessaging.Scanner{},
		&linenotify.Scanner{},
		&linkpreview.Scanner{},
		&liveagent.Scanner{},
		&livestorm.Scanner{},
		&loadmill.Scanner{},
		&locationiq.Scanner{},
		&loggly.Scanner{},
		&loginradius.Scanner{},
		&logzio.Scanner{},
		&lokalisetoken.Scanner{},
		&loyverse.Scanner{},
		&lunchmoney.Scanner{},
		&luno.Scanner{},
		// &m3o.Scanner{},
		&madkudu.Scanner{},
		&magicbell.Scanner{},
		// &magnetic.Scanner{},
		&mailboxlayer.Scanner{},
		&mailchimp.Scanner{},
		&mailerlite.Scanner{},
		&mailgun.Scanner{},
		&mailjetbasicauth.Scanner{},
		&mailjetsms.Scanner{},
		&mailmodo.Scanner{},
		&mailsac.Scanner{},
		&mandrill.Scanner{},
		// &manifest.Scanner{},
		&mapbox.Scanner{},
		&mapquest.Scanner{},
		&marketstack.Scanner{},
		&mattermostpersonaltoken.Scanner{},
		&mavenlink.Scanner{},
		&maxmindlicensev1.Scanner{},
		&maxmindlicensev2.Scanner{},
		&meaningcloud.Scanner{},
		&mediastack.Scanner{},
		&meistertask.Scanner{},
		&meraki.Scanner{},
		&mesibo.Scanner{},
		&messagebird.Scanner{},
		&metaapi.Scanner{},
		&metabase.Scanner{},
		&metrilo.Scanner{},
		&microsoftteamswebhook.Scanner{},
		&mindmeister.Scanner{},
		&miro.Scanner{},
		&mite.Scanner{},
		&mixmax.Scanner{},
		// &mixpanel.Scanner{},
		&mockaroo.Scanner{},
		&moderation.Scanner{},
		&monday.Scanner{},
		&mongodb.Scanner{},
		&monkeylearn.Scanner{},
		&moonclerk.Scanner{},
		&moosend.Scanner{},
		&moralis.Scanner{},
		&mrticktock.Scanner{},
		&mux.Scanner{},
		&myfreshworks.Scanner{},
		&myintervals.Scanner{},
		// &nasdaqdatalink.Scanner{},
		&nethunt.Scanner{},
		&netlify.Scanner{},
		&netsuite.Scanner{},
		&neutrinoapi.Scanner{},
		&newrelicpersonalapikey.Scanner{},
		&newsapi.Scanner{},
		&newscatcher.Scanner{},
		&nexmoapikey.Scanner{},
		&nftport.Scanner{},
		&ngc.Scanner{},
		&ngrok.Scanner{},
		&nicereply.Scanner{},
		&nightfall.Scanner{},
		&nimble.Scanner{},
		&noticeable.Scanner{},
		&notion.Scanner{},
		&nozbeteams.Scanner{},
		&npmtoken.Scanner{},
		&npmtokenv2.Scanner{},
		&nugetapikey.Scanner{},
		&numverify.Scanner{},
		&nutritionix.Scanner{},
		&nvapi.Scanner{},
		&nylas.Scanner{},
		&oanda.Scanner{},
		&okta.Scanner{},
		&omnisend.Scanner{},
		&onedesk.Scanner{},
		&onelogin.Scanner{},
		&onepagecrm.Scanner{},
		&onesignal.Scanner{},
		&onfleet.Scanner{},
		&oopspam.Scanner{},
		&openai.Scanner{},
		&opencagedata.Scanner{},
		&openuv.Scanner{},
		&openvpn.Scanner{},
		&openweather.Scanner{},
		&opsgenie.Scanner{},
		&optimizely.Scanner{},
		&overloop.Scanner{},
		&owlbot.Scanner{},
		&packagecloud.Scanner{},
		&pagarme.Scanner{},
		&pagerdutyapikey.Scanner{},
		&pandadoc.Scanner{},
		&pandascore.Scanner{},
		&paperform.Scanner{},
		&paralleldots.Scanner{},
		&parsehub.Scanner{},
		&parsers.Scanner{},
		&parseur.Scanner{},
		&partnerstack.Scanner{},
		&pastebin.Scanner{},
		&paydirtapp.Scanner{},
		&paymoapp.Scanner{},
		&paymongo.Scanner{},
		&paypaloauth.Scanner{},
		&paystack.Scanner{},
		&pdflayer.Scanner{},
		&pdfshift.Scanner{},
		&peopledatalabs.Scanner{},
		&pepipost.Scanner{},
		&percy.Scanner{},
		&pinata.Scanner{},
		&pipedream.Scanner{},
		&pipedrive.Scanner{},
		&pivotaltracker.Scanner{},
		&pixabay.Scanner{},
		// &plaidkey.Scanner{},
		&planetscale.Scanner{},
		&planetscaledb.Scanner{},
		&planviewleankit.Scanner{},
		&planyo.Scanner{},
		&plivo.Scanner{},
		&podio.Scanner{},
		&pollsapi.Scanner{},
		&poloniex.Scanner{},
		&polygon.Scanner{},
		&portainer.Scanner{},
		&portainertoken.Scanner{},
		&positionstack.Scanner{},
		&postageapp.Scanner{},
		&postbacks.Scanner{},
		&postgres.Scanner{},
		&posthog.Scanner{},
		&postman.Scanner{},
		&postmark.Scanner{},
		&powrbot.Scanner{},
		&prefect.Scanner{},
		&privacy.Scanner{},
		&privatekey.Scanner{},
		&prodpad.Scanner{},
		&prospectcrm.Scanner{},
		&protocolsio.Scanner{},
		&proxycrawl.Scanner{},
		&pubnubpublishkey.Scanner{},
		&pubnubsubscriptionkey.Scanner{},
		&pulumi.Scanner{},
		&purestake.Scanner{},
		&pushbulletapikey.Scanner{},
		&pusherchannelkey.Scanner{},
		&pypi.Scanner{},
		&qase.Scanner{},
		&qualaroo.Scanner{},
		&qubole.Scanner{},
		&rabbitmq.Scanner{},
		&railwayapp.Scanner{},
		&ramp.Scanner{},
		&rapidapi.Scanner{},
		// &raven.Scanner{},
		&rawg.Scanner{},
		&razorpay.Scanner{},
		&reachmail.Scanner{},
		&readme.Scanner{},
		&reallysimplesystems.Scanner{},
		&rebrandly.Scanner{},
		&rechargepayments.Scanner{},
		&redis.Scanner{},
		&refiner.Scanner{},
		&rentman.Scanner{},
		&repairshopr.Scanner{},
		&replicate.Scanner{},
		&replyio.Scanner{},
		&requestfinance.Scanner{},
		// &restpack.Scanner{},
		&restpackhtmltopdfapi.Scanner{},
		&restpackscreenshotapi.Scanner{},
		&revampcrm.Scanner{},
		&ringcentral.Scanner{},
		&ritekit.Scanner{},
		&roaring.Scanner{},
		&robinhoodcrypto.Scanner{},
		&rocketreach.Scanner{},
		// &rockset.Scanner{},
		&roninapp.Scanner{},
		&route4me.Scanner{},
		&rownd.Scanner{},
		&rubygems.Scanner{},
		&runrunit.Scanner{},
		&saladcloudapikey.Scanner{},
		&salesblink.Scanner{},
		&salescookie.Scanner{},
		&salesflare.Scanner{},
		&salesforce.Scanner{},
		&salesmate.Scanner{},
		&sanity.Scanner{},
		&satismeterprojectkey.Scanner{},
		&satismeterwritekey.Scanner{},
		&saucelabs.Scanner{},
		&scalewaykey.Scanner{},
		&scalr.Scanner{},
		&scrapeowl.Scanner{},
		&scraperapi.Scanner{},
		&scraperbox.Scanner{},
		&scrapestack.Scanner{},
		&scrapfly.Scanner{},
		&scrapingant.Scanner{},
		&scrapingbee.Scanner{},
		&screenshotapi.Scanner{},
		&screenshotlayer.Scanner{},
		&scrutinizerci.Scanner{},
		&securitytrails.Scanner{},
		&segmentapikey.Scanner{},
		&selectpdf.Scanner{},
		&semaphore.Scanner{},
		&sendbird.Scanner{},
		&sendbirdorganizationapi.Scanner{},
		&sendgrid.Scanner{},
		&sendinbluev2.Scanner{},
		&sentrytokenv1.Scanner{},
		&sentrytokenv2.Scanner{},
		&serphouse.Scanner{},
		&serpstack.Scanner{},
		&sheety.Scanner{},
		&sherpadesk.Scanner{},
		&shipday.Scanner{},
		&shodankey.Scanner{},
		&shopify.Scanner{},
		&shortcut.Scanner{},
		&shotstack.Scanner{},
		&shutterstock.Scanner{},
		&shutterstockoauth.Scanner{},
		&signable.Scanner{},
		&signalwire.Scanner{},
		&signaturit.Scanner{},
		&signupgenius.Scanner{},
		&sigopt.Scanner{},
		&simfin.Scanner{},
		&simplesat.Scanner{},
		&simplynoted.Scanner{},
		&simvoly.Scanner{},
		&sinchmessage.Scanner{},
		&sirv.Scanner{},
		&siteleaf.Scanner{},
		&skrappio.Scanner{},
		&skybiometry.Scanner{},
		&slack.Scanner{}, // has 4 secret types
		&slackwebhook.Scanner{},
		&smartsheets.Scanner{},
		&smartystreets.Scanner{},
		&smooch.Scanner{},
		&snipcart.Scanner{},
		&snowflake.Scanner{},
		&snykkey.Scanner{},
		&sonarcloud.Scanner{},
		&sourcegraph.Scanner{},
		&sourcegraphcody.Scanner{},
		// &sparkpost.Scanner{},
		&speechtextai.Scanner{},
		&splunkobservabilitytoken.Scanner{},
		&spoonacular.Scanner{},
		&sportsmonk.Scanner{},
		// &spotifykey.Scanner{},
		&sqlserver.Scanner{},
		&square.Scanner{},
		&squareapp.Scanner{},
		&squarespace.Scanner{},
		&squareup.Scanner{},
		&sslmate.Scanner{},
		&statuscake.Scanner{},
		&statuspage.Scanner{},
		&statuspal.Scanner{},
		&stitchdata.Scanner{},
		&stockdata.Scanner{},
		&storecove.Scanner{},
		&stormboard.Scanner{},
		&stormglass.Scanner{},
		&storyblok.Scanner{},
		&storychief.Scanner{},
		&strava.Scanner{},
		&streak.Scanner{},
		&stripe.Scanner{},
		&stripo.Scanner{},
		&stytch.Scanner{},
		&sugester.Scanner{},
		&sumologickey.Scanner{},
		&supabasetoken.Scanner{},
		&supernotesapi.Scanner{},
		&surveyanyplace.Scanner{},
		&surveybot.Scanner{},
		&surveysparrow.Scanner{},
		&survicate.Scanner{},
		&swell.Scanner{},
		&swiftype.Scanner{},
		&tailscale.Scanner{},
		&tallyfy.Scanner{},
		&tatumio.Scanner{},
		&taxjar.Scanner{},
		&teamgate.Scanner{},
		&teamworkcrm.Scanner{},
		&teamworkdesk.Scanner{},
		&teamworkspaces.Scanner{},
		&technicalanalysisapi.Scanner{},
		&tefter.Scanner{},
		&telegrambottoken.Scanner{},
		&teletype.Scanner{},
		&telnyx.Scanner{},
		&terraformcloudpersonaltoken.Scanner{},
		&testingbot.Scanner{},
		&textmagic.Scanner{},
		&theoddsapi.Scanner{},
		&thinkific.Scanner{},
		&thousandeyes.Scanner{},
		&ticketmaster.Scanner{},
		&tickettailor.Scanner{},
		&tiingo.Scanner{},
		&timecamp.Scanner{},
		&timezoneapi.Scanner{},
		&tineswebhook.Scanner{},
		&tmetric.Scanner{},
		&todoist.Scanner{},
		// &toggltrack.Scanner{},
		&tokeet.Scanner{},
		&tomorrowio.Scanner{},
		&tomtom.Scanner{},
		&tradier.Scanner{},
		&transferwise.Scanner{},
		&travelpayouts.Scanner{},
		&travisci.Scanner{},
		&trelloapikey.Scanner{},
		&trufflehogenterprise.Scanner{},
		&twelvedata.Scanner{},
		&twilio.Scanner{},
		&twilioapikey.Scanner{},
		&twist.Scanner{},
		&twitch.Scanner{},
		&twitchaccesstoken.Scanner{},
		&twitterconsumerkey.Scanner{},
		&twitterv1.Scanner{},
		&twitterv2.Scanner{},
		&tyntec.Scanner{},
		&typeformv1.Scanner{},
		&typeformv2.Scanner{},
		&typetalk.Scanner{},
		&ubidots.Scanner{},
		&uclassify.Scanner{},
		&unifyid.Scanner{},
		&unplugg.Scanner{},
		&unsplash.Scanner{},
		&upcdatabase.Scanner{},
		&uplead.Scanner{},
		&uploadcare.Scanner{},
		&uptimerobot.Scanner{},
		&upwave.Scanner{},
		&uri.Scanner{},
		&urlscan.Scanner{},
		&userflow.Scanner{},
		&userstack.Scanner{},
		&vagrantcloudpersonaltoken.Scanner{},
		&vatlayer.Scanner{},
		&vbout.Scanner{},
		&vercel.Scanner{},
		&verifier.Scanner{},
		&verimail.Scanner{},
		&veriphone.Scanner{},
		&versioneye.Scanner{},
		&viewneo.Scanner{},
		&virustotal.Scanner{},
		&visualcrossing.Scanner{},
		&voiceflow.Scanner{},
		&voicegain.Scanner{},
		&voodoosms.Scanner{},
		&vouchery.Scanner{},
		&vpnapi.Scanner{},
		&vultrapikey.Scanner{},
		&vyte.Scanner{},
		&walkscore.Scanner{},
		&weatherbit.Scanner{},
		&weatherstack.Scanner{},
		&web3storage.Scanner{},
		&webex.Scanner{},
		&webflow.Scanner{},
		&webscraper.Scanner{},
		&webscraping.Scanner{},
		&websitepulse.Scanner{},
		&weightsandbiases.Scanner{},
		// &wepay.Scanner{},
		&whoxy.Scanner{},
		&wistia.Scanner{},
		&wiz.Scanner{},
		&worksnaps.Scanner{},
		&workstack.Scanner{},
		&worldcoinindex.Scanner{},
		&worldweather.Scanner{},
		&wrike.Scanner{},
		&yandex.Scanner{},
		&yelp.Scanner{},
		&youneedabudget.Scanner{},
		&yousign.Scanner{},
		&youtubeapikey.Scanner{},
		// &zapierwebhook.Scanner{},
		&zendeskapi.Scanner{},
		&zenkitapi.Scanner{},
		&zenrows.Scanner{},
		&zenscrape.Scanner{},
		&zenserp.Scanner{},
		&zeplin.Scanner{},
		&zerobounce.Scanner{},
		&zerotier.Scanner{},
		&zipapi.Scanner{},
		&zipbooks.Scanner{},
		&zipcodeapi.Scanner{},
		&zipcodebase.Scanner{},
		&zohocrm.Scanner{},
		&zonkafeedback.Scanner{},
		&zulipchat.Scanner{},
	}
}

func DefaultDetectors() []detectors.Detector {
	detectorList := buildDetectorList()

	// Automatically initialize all detectors that implement
	// EndpointCustomizer and/or CloudProvider interfaces.
	for _, d := range detectorList {
		customizer, ok := d.(detectors.EndpointCustomizer)
		if !ok {
			continue
		}
		// Default to always use the cloud endpoints (if available) and the found endpoints.
		customizer.UseFoundEndpoints(true)
		customizer.UseCloudEndpoint(true)
		if cloudProvider, ok := d.(detectors.CloudProvider); ok {
			customizer.SetCloudEndpoint(cloudProvider.CloudEndpoint())
		}
	}

	return detectorList
}

func DefaultDetectorTypesImplementing[T any]() map[detectorspb.DetectorType]struct{} {
	out := make(map[detectorspb.DetectorType]struct{})
	for _, detector := range DefaultDetectors() {
		if _, ok := detector.(T); ok {
			out[detector.Type()] = struct{}{}
		}
	}
	return out
}
